@@ -2,9 +2,8 @@ package Froody::Argument::Multipart;
 use strict;
 use warnings;
 use base 'Froody::Argument';
-use Carp qw( croak );
 
-sub type { 'multipart' , 'file' }
+sub type { 'multipart' }
 
 sub process {
   my ($class, $param, $check) = @_;
